0.9.9 API documentation: intersect.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Functions
intersect.hpp File Reference

GLM_GTX_intersect More...

Go to the source code of this file.

## Functions
template<typename genType >
GLM_FUNC_DECL bool | intersectLineSphere (genType const &point0, genType const &point1, genType const &sphereCenter, typename genType::value_type sphereRadius, genType &intersectionPosition1, genType &intersectionNormal1, genType &intersectionPosition2=genType(), genType &intersectionNormal2=genType())
| Compute the intersection of a line and a sphere. More...
template<typename genType >
GLM_FUNC_DECL bool | intersectLineTriangle (genType const &orig, genType const &dir, genType const &vert0, genType const &vert1, genType const &vert2, genType &position)
| Compute the intersection of a line and a triangle. More...
template<typename genType >
GLM_FUNC_DECL bool | intersectRayPlane (genType const &orig, genType const &dir, genType const &planeOrig, genType const &planeNormal, typename genType::value_type &intersectionDistance)
| Compute the intersection of a ray and a plane. More...
template<typename genType >
GLM_FUNC_DECL bool | intersectRaySphere (genType const &rayStarting, genType const &rayNormalizedDirection, genType const &sphereCenter, typename genType::value_type const sphereRadiusSquared, typename genType::value_type &intersectionDistance)
| Compute the intersection distance of a ray and a sphere. More...
template<typename genType >
GLM_FUNC_DECL bool | intersectRaySphere (genType const &rayStarting, genType const &rayNormalizedDirection, genType const &sphereCenter, const typename genType::value_type sphereRadius, genType &intersectionPosition, genType &intersectionNormal)
| Compute the intersection of a ray and a sphere. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL bool | intersectRayTriangle (vec< 3, T, Q > const &orig, vec< 3, T, Q > const &dir, vec< 3, T, Q > const &v0, vec< 3, T, Q > const &v1, vec< 3, T, Q > const &v2, vec< 2, T, Q > &baryPosition, T &distance)
| Compute the intersection of a ray and a triangle. More...

## Detailed Description

GLM_GTX_intersect

See also
  Core features (dependence)
  GLM_GTX_closest_point (dependence)

Definition in file intersect.hpp.